import { Injectable } from '@nestjs/common';
import { promises as fs } from 'fs';
import {join} from "path";
import {
  createNft,
  initializeApi,
  getKeyringFromSeed,
  WaitUntil,
  safeDisconnect,
  NFTCreatedEvent
} from "ternoa-js";

import { request, gql } from "graphql-request";

type NftType = {
  owner: string;
  nftId: string;
  offchainData: string;
  collectionId: string;
  royalty: number;
};

@Injectable()
export class AppService {

  async retrieveNFT(nft_id): Promise<NftType | undefined> {
    try {
      const query = (id: number) => gql`
        {
          nftEntity(id: "${id}") {
            owner
            nftId
            offchainData
            collectionId
            royalty
          }
        }
    `;

      const response = await request<{ nftEntity: NftType }>(
          "https://indexer-alphanet.ternoa.dev",
          query(nft_id)
      );
      return response.nftEntity;
    } catch (error) {
      console.error(error);
      return undefined;
    }
  }

  async storeNFT(message){
    let result = 0;
    try {
      await initializeApi();
      const keyring = await getKeyringFromSeed("//TernoaTestAccount");
      const nftDatas = await createNft(
          message,
          0,
          undefined,
          false,
          keyring,
          WaitUntil.BlockInclusion
      );
      console.log("The on-chain NFT id is: ", nftDatas.nftId);
      result = nftDatas.nftId;
      await safeDisconnect();
      //process.exit();
    } catch (e) {
      console.error(e);
      result = -1;
    } finally {
      await safeDisconnect();
      //process.exit();
    }
    return result
  }
}
